package com.skywang.service;

import android.os.IBinder;
import android.app.Service;
import android.content.Intent;
import android.util.Log;

import java.lang.Thread;
/**
 * @desc 服务：每隔200ms将一个数字+2并通过广播发送出去
 * @author skywang
 *
 */
public class StartServiceImpl extends Service {
	private static final String TAG = "skywang-->StartServiceImpl";
	
	// 发送的广播对应的action
	private static final String COUNT_ACTION = "com.skywang.service.startservice.COUNT_ACTION";
	
	// 线程：用来实现每隔200ms发送广播
	private static CountThread mCountThread = null;
	// 数字的索引
	private static int index = 0;
	
	@Override
	public void onCreate() {
		Log.d(TAG, "onCreate");
		super.onCreate();
	}
	
	@Override
	public void onDestroy() {
		Log.d(TAG, "onDestroy");

		// 终止服务
		if ( mCountThread != null) {
			mCountThread.interrupt();
			mCountThread = null;
		}
		super.onDestroy();
	}
	
	@Override
	public int onStartCommand(Intent intent, int flags, int startId) {
		Log.d(TAG, "onStartCommand");
		
		// 非首次运行服务时，执行下面操作
		// 目的是将index设为0
		if ( mCountThread != null) {
			Log.d(TAG, "mCountThread != null");
			index = 0;
			return START_STICKY;
		}
		
		Log.d(TAG, "start thread");
		// 首次运行时，创建并启动线程
		mCountThread = new CountThread();
		mCountThread.start();
		
		return START_STICKY;
	}
	
	@Override
	public IBinder onBind(Intent intent) {
		Log.d(TAG, "onBind");
		return null;
	}
	
	private class CountThread extends Thread {
		@Override 
		public void run() {
			index = 0;
			try {
				while (true) {
					// 将数字+2,
					index += 2;					
					
					// 将index通过广播发送出去
					Intent intent = new Intent(COUNT_ACTION);
					intent.putExtra("count", index);
					sendBroadcast(intent);
//					Log.d(TAG, "CountThread index:"+index);
					
					// 若数字>=100 则退出
					if (index >= 100) {
						if ( mCountThread != null) {
							mCountThread = null;
						}
						return ;
					}
					
					// 修改200ms
					this.sleep(100);
				}
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	}
}