package com.skywang.service;

import android.os.Bundle;
import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.view.View;
import android.widget.Button;
import android.widget.ProgressBar;
import android.util.Log;

public class StartServiceTest extends Activity {
	private static final String TAG = "skywang-->StartServiceTest";

	private static final String COUNT_ACTION = "com.skywang.service.startservice.COUNT_ACTION";
	private CurrentReceiver mReceiver;
	private Button mStart = null;
	private Button mStop = null;
	private Intent mIntent = null;
	private Intent mServiceIntent = null; 
	private ProgressBar mProgressBar = null;
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.start_service_test);
		

        mStart = (Button) findViewById(R.id.start);
        mStart.setOnClickListener(new View.OnClickListener() {
			
			@Override
			public void onClick(View arg0) {
				Log.d(TAG, "click start button");
				// 显示“结束”按钮
				mStop.setVisibility(View.VISIBLE);
				// 将“开始”按钮更名为“重启”按钮
				mStart.setText(R.string.text_restart);
				// 启动服务，用来更新进度
				if (mServiceIntent == null) 
					mServiceIntent = new Intent("com.skywang.service.StartService");
				startService(mServiceIntent);
			}
		});
        

        mStop = (Button) findViewById(R.id.stop);
        mStop.setOnClickListener(new View.OnClickListener() {
			
			@Override
			public void onClick(View view) {
				Log.d(TAG, "click stop button");
				if (mServiceIntent != null) {
					// 结束服务。
					stopService(mServiceIntent);
					mServiceIntent = null;
				}
			}
		});
        mStop.setVisibility(View.INVISIBLE);
        
        mProgressBar = (ProgressBar) findViewById(R.id.pbar_def);
        // 隐藏进度条
    	mProgressBar.setVisibility(View.INVISIBLE);
        
        // 动态注册监听COUNT_ACTION广播
        mReceiver = new CurrentReceiver();
        IntentFilter filter = new IntentFilter();
        filter.addAction(COUNT_ACTION);
        this.registerReceiver(mReceiver, filter);
	}

    @Override  
    public void onDestroy(){  
        super.onDestroy();  
  
        if(mIntent != null)
            stopService(mIntent);
        
        if(mReceiver != null)
        	this.unregisterReceiver(mReceiver);
    }
    
    /**
     * @desc 更新进度条
     * @param index
     */
    private void updateProgressBar(int index) {
        int max = mProgressBar.getMax();

        if (index < max) {
            mProgressBar.setProgress(index);
            mProgressBar.setVisibility(View.VISIBLE);
        } else {
        	// 隐藏进度条
        	mProgressBar.setVisibility(View.INVISIBLE);
			// 隐藏“结束”按钮
			mStop.setVisibility(View.INVISIBLE);
			// 将“重启”按钮更名为“开始”按钮
			mStart.setText(R.string.text_start);
        }
//        Log.d(TAG, "progress : "+mProgressBar.getProgress()+" , max : "+max);
    }
    
    /**
     * @desc 广播：监听COUNT_ACTION，获取索引值，并根据索引值来更新进度条
     * @author skywang
     *
     */
    private class CurrentReceiver extends BroadcastReceiver {
    	@Override
    	public void onReceive(Context context, Intent intent) {
    		String action  = intent.getAction();
    		if (COUNT_ACTION.equals(action)) {
    			int index = intent.getIntExtra("count", 0);
    			updateProgressBar(index);
    		}
    	}
    }
}
